@@ -66,6 +66,14 @@ igloo_error_t igloo_cs_to_upper_first(char *str);
  */
 igloo_error_t igloo_cs_to_hex(const void *in, char **res, size_t len) igloo_ATTR_F_WARN_UNUSED_RESULT;
 
+/*
+ * A replacement for strcasestr() on systems without it.
+ * On systems with it, the native function should be used.
+ *
+ * This function considers case only for ASCII characters.
+ */
+const char *igloo_cs_strcasestr(const char *haystack, const char *needle);
+
 #ifdef __cplusplus
 }
 #endif
