@@ -70,7 +70,7 @@ igloo_error_t igloo_sp_ref(const char *str, const char **ref, igloo_ro_t instanc
  * Returns:
  *  The error code for the operation.
  */
-igloo_error_t igloo_sp_replace(const char *str, const char **ref, igloo_ro_t instance) igloo_ATTR_F_WARN_UNUSED_RESULT;
+igloo_error_t igloo_sp_replace(const char *str, const char **ref, igloo_ro_t instance);
 
 /* Frees a reference to a string.
  * Parameters:
@@ -81,7 +81,7 @@ igloo_error_t igloo_sp_replace(const char *str, const char **ref, igloo_ro_t ins
  * Returns:
  *  The error code for the operation.
  */
-igloo_error_t igloo_sp_unref(const char **ref, igloo_ro_t instance) igloo_ATTR_F_WARN_UNUSED_RESULT;
+igloo_error_t igloo_sp_unref(const char **ref, igloo_ro_t instance);
 
 #ifdef __cplusplus
 }
