@@ -62,7 +62,7 @@ static igloo_error_t igloo_cs_to_long(const char *str, long int *res)
     char *rem = NULL;
 
     if (!str || !res)
-        return igloo_ERROR_FAULT; 
+        return igloo_ERROR_FAULT;
 
     error = igloo_cs_skip_spaces(&str);
     if (error != igloo_ERROR_NONE)
@@ -96,7 +96,7 @@ igloo_error_t igloo_cs_to_int(const char *str, int *res)
     long int val;
 
     if (!str || !res)
-        return igloo_ERROR_FAULT; 
+        return igloo_ERROR_FAULT;
 
     error = igloo_cs_to_long(str, &val);
     if (error != igloo_ERROR_NONE)
@@ -115,7 +115,7 @@ igloo_error_t igloo_cs_to_uint(const char *str, unsigned int *res)
     long int val;
 
     if (!str || !res)
-        return igloo_ERROR_FAULT; 
+        return igloo_ERROR_FAULT;
 
     error = igloo_cs_to_long(str, &val);
     if (error != igloo_ERROR_NONE)
@@ -227,3 +227,50 @@ igloo_error_t igloo_cs_to_hex(const void *in, char **res, size_t len)
 
     return igloo_ERROR_NONE;
 }
+
+const char *igloo_cs_strcasestr(const char *haystack, const char *needle) {
+    if (!haystack || !needle)
+        return NULL;
+
+    for (const char *start = haystack; *start; start++) {
+        const char *p = start;
+        const char *c = needle;
+        char cc = 1;
+
+        while (true) {
+            char cp = *(p++);
+
+            cc = *(c++);
+
+            if (cp == cc) {
+                if (cp == 0)
+                    return start;
+                continue;
+            }
+
+            if (!cc)
+                break;
+
+            if (!cp) {
+                cc = 1;
+                break;
+            }
+
+            if (cp >= 'A' && cp <= 'Z')
+                cp = cp - 'A' + 'a';
+
+            if (cc >= 'A' && cc <= 'Z')
+                cc = cc - 'A' + 'a';
+
+            if (cp != cc) {
+                cc = 1;
+                break;
+            }
+        }
+
+        if (!cc)
+            return start;
+    }
+
+    return NULL;
+}
